==> openflowplugin-extension-nicira-0.10.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/tp/dst/grouping/NxmNxCtTpDstBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.tp.dst.grouping;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Uint16;

/**
 * Class that builds {@link NxmNxCtTpDstBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxmNxCtTpDstBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxmNxCtTpDstBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxmNxCtTpDstBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxmNxCtTpDstBuilder
 * @see Builder
 *
 */
public class NxmNxCtTpDstBuilder implements Builder<NxmNxCtTpDst> {

    private Uint16 _ctTpDst;
    private Uint16 _mask;


    Map<Class<? extends Augmentation<NxmNxCtTpDst>>, Augmentation<NxmNxCtTpDst>> augmentation = Collections.emptyMap();

    public NxmNxCtTpDstBuilder() {
    }

    public NxmNxCtTpDstBuilder(NxmNxCtTpDst base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxmNxCtTpDst>>, Augmentation<NxmNxCtTpDst>> aug =((AugmentationHolder<NxmNxCtTpDst>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._ctTpDst = base.getCtTpDst();
        this._mask = base.getMask();
    }


    public Uint16 getCtTpDst() {
        return _ctTpDst;
    }
    
    public Uint16 getMask() {
        return _mask;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxmNxCtTpDst>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxmNxCtTpDstBuilder setCtTpDst(final Uint16 value) {
        this._ctTpDst = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setCtTpDst(Uint16)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxmNxCtTpDstBuilder setCtTpDst(final Integer value) {
        return setCtTpDst(CodeHelpers.compatUint(value));
    }
    
    public NxmNxCtTpDstBuilder setMask(final Uint16 value) {
        this._mask = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setMask(Uint16)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxmNxCtTpDstBuilder setMask(final Integer value) {
        return setMask(CodeHelpers.compatUint(value));
    }
    
    public NxmNxCtTpDstBuilder addAugmentation(Class<? extends Augmentation<NxmNxCtTpDst>> augmentationType, Augmentation<NxmNxCtTpDst> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxmNxCtTpDstBuilder removeAugmentation(Class<? extends Augmentation<NxmNxCtTpDst>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxmNxCtTpDst build() {
        return new NxmNxCtTpDstImpl(this);
    }

    private static final class NxmNxCtTpDstImpl
        extends AbstractAugmentable<NxmNxCtTpDst>
        implements NxmNxCtTpDst {
    
        private final Uint16 _ctTpDst;
        private final Uint16 _mask;
    
        NxmNxCtTpDstImpl(NxmNxCtTpDstBuilder base) {
            super(base.augmentation);
            this._ctTpDst = base.getCtTpDst();
            this._mask = base.getMask();
        }
    
        @Override
        public Uint16 getCtTpDst() {
            return _ctTpDst;
        }
        
        @Override
        public Uint16 getMask() {
            return _mask;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ctTpDst);
            result = prime * result + Objects.hashCode(_mask);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxmNxCtTpDst.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            NxmNxCtTpDst other = (NxmNxCtTpDst)obj;
            if (!Objects.equals(_ctTpDst, other.getCtTpDst())) {
                return false;
            }
            if (!Objects.equals(_mask, other.getMask())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxmNxCtTpDstImpl otherImpl = (NxmNxCtTpDstImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxmNxCtTpDst>>, Augmentation<NxmNxCtTpDst>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxmNxCtTpDst");
            CodeHelpers.appendValue(helper, "_ctTpDst", _ctTpDst);
            CodeHelpers.appendValue(helper, "_mask", _mask);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.11.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/tp/dst/grouping/NxmNxCtTpDstBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.tp.dst.grouping;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Deprecated;
import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Uint16;

/**
 * Class that builds {@link NxmNxCtTpDstBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxmNxCtTpDstBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxmNxCtTpDstBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxmNxCtTpDstBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxmNxCtTpDstBuilder
 * @see Builder
 *
 */
public class NxmNxCtTpDstBuilder implements Builder<NxmNxCtTpDst> {

    private Uint16 _ctTpDst;
    private Uint16 _mask;


    Map<Class<? extends Augmentation<NxmNxCtTpDst>>, Augmentation<NxmNxCtTpDst>> augmentation = Collections.emptyMap();

    public NxmNxCtTpDstBuilder() {
    }

    public NxmNxCtTpDstBuilder(NxmNxCtTpDst base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxmNxCtTpDst>>, Augmentation<NxmNxCtTpDst>> aug =((AugmentationHolder<NxmNxCtTpDst>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._ctTpDst = base.getCtTpDst();
        this._mask = base.getMask();
    }


    public Uint16 getCtTpDst() {
        return _ctTpDst;
    }
    
    public Uint16 getMask() {
        return _mask;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxmNxCtTpDst>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public NxmNxCtTpDstBuilder setCtTpDst(final Uint16 value) {
        this._ctTpDst = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setCtTpDst(Uint16)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxmNxCtTpDstBuilder setCtTpDst(final Integer value) {
        return setCtTpDst(CodeHelpers.compatUint(value));
    }
    
    public NxmNxCtTpDstBuilder setMask(final Uint16 value) {
        this._mask = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setMask(Uint16)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxmNxCtTpDstBuilder setMask(final Integer value) {
        return setMask(CodeHelpers.compatUint(value));
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public NxmNxCtTpDstBuilder addAugmentation(Augmentation<NxmNxCtTpDst> augmentation) {
        return doAddAugmentation(augmentation.implementedInterface(), augmentation);
    }
    
    /**
      * Add or remove an augmentation to this builder's product.
      *
      * @param augmentationType augmentation type to be added or removed
      * @param augmentationValue augmentation value, null if the augmentation type should be removed
      * @return this builder
      * @deprecated Use either {@link #addAugmentation(Augmentation)} or {@link #removeAugmentation(Class)} instead.
      */
    @Deprecated(forRemoval = true)
    public NxmNxCtTpDstBuilder addAugmentation(Class<? extends Augmentation<NxmNxCtTpDst>> augmentationType, Augmentation<NxmNxCtTpDst> augmentationValue) {
        return augmentationValue == null ? removeAugmentation(augmentationType) : doAddAugmentation(augmentationType, augmentationValue);
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public NxmNxCtTpDstBuilder removeAugmentation(Class<? extends Augmentation<NxmNxCtTpDst>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }
    
    private NxmNxCtTpDstBuilder doAddAugmentation(Class<? extends Augmentation<NxmNxCtTpDst>> augmentationType, Augmentation<NxmNxCtTpDst> augmentationValue) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }

    @Override
    public NxmNxCtTpDst build() {
        return new NxmNxCtTpDstImpl(this);
    }

    private static final class NxmNxCtTpDstImpl
        extends AbstractAugmentable<NxmNxCtTpDst>
        implements NxmNxCtTpDst {
    
        private final Uint16 _ctTpDst;
        private final Uint16 _mask;
    
        NxmNxCtTpDstImpl(NxmNxCtTpDstBuilder base) {
            super(base.augmentation);
            this._ctTpDst = base.getCtTpDst();
            this._mask = base.getMask();
        }
    
        @Override
        public Uint16 getCtTpDst() {
            return _ctTpDst;
        }
        
        @Override
        public Uint16 getMask() {
            return _mask;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ctTpDst);
            result = prime * result + Objects.hashCode(_mask);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxmNxCtTpDst.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            NxmNxCtTpDst other = (NxmNxCtTpDst)obj;
            if (!Objects.equals(_ctTpDst, other.getCtTpDst())) {
                return false;
            }
            if (!Objects.equals(_mask, other.getMask())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxmNxCtTpDstImpl otherImpl = (NxmNxCtTpDstImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxmNxCtTpDst>>, Augmentation<NxmNxCtTpDst>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxmNxCtTpDst");
            CodeHelpers.appendValue(helper, "_ctTpDst", _ctTpDst);
            CodeHelpers.appendValue(helper, "_mask", _mask);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
